[![Python tests](https://github.com/FusionSolutions/python-fsrpcclient/actions/workflows/python-package.yml/badge.svg?branch=master)](https://github.com/FusionSolutions/python-fsrpcclient/actions/workflows/python-package.yml)
# Fusion Solutions RPC client

## Introduction

Python RPC client for JSONRPC and FSP protocol through TCP (IPv4 and IPv6) and IPC socket.

## Installation

Requires python version 3.8 or later.

To install the latest release on [PyPI](https://pypi.org/project/python-fsrpcclient/),
simply run:

```shell
pip3 install python-fsrpcclient
```

Or to install the latest version, run:

```shell
git clone https://github.com/FusionSolutions/python-fsrpcclient.git
cd python-fsrpcclient
python3 setup.py install
```

## Python library

### Usage

TODO

## Contribution

Bug reports, constructive criticism and suggestions are welcome. If you have some create an issue on [github](https://github.com/FusionSolutions/python-fsrpcclient/issues).

## Copyright

All of the code in this distribution is Copyright (c) 2021 Fusion Solutions Kft.

The utility is made available under the GNU General Public license. The included LICENSE file describes this in detail.

## Warranty

THIS SOFTWARE IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK AS TO THE USE OF THIS SOFTWARE IS WITH YOU.

IN NO EVENT WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR REDISTRIBUTE THE LIBRARY, BE LIABLE TO YOU FOR ANY DAMAGES, EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.

Again, see the included LICENSE file for specific legal details.
